scoretools.get_measure_that_stops_with_container
================================================

.. autofunction:: abjad.tools.scoretools.get_measure_that_stops_with_container.get_measure_that_stops_with_container
